==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudwatch/kotlin/outputs/GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestination.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudwatch.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property cloudwatchLogs Configures CloudWatch Logs as a findings destination.
 * @property firehose Configures Kinesis Firehose as a findings destination.
 * @property s3 Configures S3 as a findings destination.
 */
public data class GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestination(
    public val cloudwatchLogs:
    GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestinationCloudwatchLogs? =
        null,
    public val firehose:
    GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestinationFirehose? = null,
    public val s3: GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestinationS3? =
        null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.cloudwatch.outputs.GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestination):
            GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestination =
            GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestination(
                cloudwatchLogs = javaType.cloudwatchLogs().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.cloudwatch.kotlin.outputs.GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestinationCloudwatchLogs.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                firehose = javaType.firehose().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.cloudwatch.kotlin.outputs.GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestinationFirehose.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                s3 = javaType.s3().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.cloudwatch.kotlin.outputs.GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestinationS3.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudwatch/kotlin/outputs/GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestination.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudwatch.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property cloudwatchLogs Configures CloudWatch Logs as a findings destination.
 * @property firehose Configures Kinesis Firehose as a findings destination.
 * @property s3 Configures S3 as a findings destination.
 */
public data class GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestination(
    public val cloudwatchLogs: GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestinationCloudwatchLogs? =
        null,
    public val firehose: GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestinationFirehose? = null,
    public val s3: GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestinationS3? =
        null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.cloudwatch.outputs.GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestination): GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestination =
            GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestination(
                cloudwatchLogs = javaType.cloudwatchLogs().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.cloudwatch.kotlin.outputs.GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestinationCloudwatchLogs.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                firehose = javaType.firehose().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.cloudwatch.kotlin.outputs.GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestinationFirehose.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                s3 = javaType.s3().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.cloudwatch.kotlin.outputs.GetLogDataProtectionPolicyDocumentStatementOperationAuditFindingsDestinationS3.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
